# -------------------------------------------------------------------------------------------------
# test_managers.py  tests dragonized managers.py                            
# -------------------------------------------------------------------------------------------------
#
# -------------------------------------------------------------------------------------------------
#                               
# -------------------------------------------------------------------------------------------------
__all__ = [ 'BaseManager', 'SyncManager', 'BaseProxy', 'Token','BaseManagerXi2', 'SyncManagerXi2', 'BaseProxyXi2', 'TokenXi2' ]


# -------------------------------------------------------------------------------------------------
# standard imports                              
# -------------------------------------------------------------------------------------------------
import os
import sys
import weakref
import threading
import array
import queue
from traceback import format_exc

# -------------------------------------------------------------------------------------------------
# multiprocessing package imports                              
# -------------------------------------------------------------------------------------------------
from multiprocessing import Process, current_process, active_children, Pool, util, connection
from multiprocessing.process import AuthenticationString
from multiprocessing.forking import exit, Popen, assert_spawning, ForkingPickler
from multiprocessing.util import Finalize, info

# -------------------------------------------------------------------------------------------------
# conditional imports                              
# -------------------------------------------------------------------------------------------------
try:
    from cPickle import PicklingError
except ImportError:
    from pickle import PicklingError

# -------------------------------------------------------------------------------------------------
# yourDragonXi class imports                               
# -------------------------------------------------------------------------------------------------
from process2xi import Process2Xi
from queue2xi  import Queue2Xi
from pipe2xi import Pipe2Xi
from lock2xi import Lock2Xi
from pool2xi import Pool2Xi
from manager2xi import Manager2Xi     
from server2xi import Server2Xi
from basemanager2xi import BaseManager2Xi
from processlocalset2xi import ProcessLocalSet2Xi
from forkingpickler2xi import ForkingPickler2Xi
from remoteerror2xi import RemoteError2Xi
from baseproxy2xi import BaseProxy2Xi
from rebuildproxy2xi import RebuildProxy2Xi
from namespace2xi import Namespace2Xi
from value2xi import Value2Xi
from iteratorproxy2xi import IteratorProxy2Xi
from acquirerproxy2xi import AcquirerProxy2Xi
from conditionproxy2xi import ConditionProxy2Xi
from eventproxy2xi import EventProxy2Xi
from namespaceproxy2xi import NamespaceProxy2Xi
from valueproxy2xi import ValueProxy2Xi
from listproxy2xi import ListProxy2Xi
from syncmanager2xi import SyncManager2Xi

# -------------------------------------------------------------------------------------------------
# yourDragonXi function imports                               
# -------------------------------------------------------------------------------------------------
from reduce_array2xi import reduce_array2xi    
from rebuild_as_list2xi import rebuild_as_list2xi
from dispatch2xi import dispatch2xi
from convert_to_error2xi import convert_to_error2xi
from all_methods2xi import all_methods2xi
from public_methods2xi import public_methods2xi
from listener_client2xi import listener_client2xi
from arrayfunction2xi import ArrayFunction2Xi
from makeproxytype2xi import MakeProxyType2Xi
from autoproxy2xi import AutoProxy2Xi

# -------------------------------------------------------------------------------------------------
# yourDragonXi type imports                               
# -------------------------------------------------------------------------------------------------
from baselistproxy2xi import BaseListProxy2Xi
from dictproxy2xi import DictProxy2Xi
from arrayproxy2xi import ArrayProxy2Xi
from poolproxy2xi import PoolProxy2Xi

#
# -------------------------------------------------------------------------------------------------   
ForkingPickler2Xi.register(array.array, reduce_array2xi) #<--- ok
#
#
view_types = [type(getattr({}, name)()) for name in ('items','keys','values')]

if view_types[0] is not list:       # only needed in Py3.0

    for view_type in view_types:
        ForkingPickler2Xi.register(view_type, rebuild_as_list2xi) #<--- ok
        import copyreg
        copyreg.pickle(view_type, rebuild_as_list2xi)
        
        
# -------------------------------------------------------------------------------------------------   
# removed from this module and imported from dragonized modules
# -------------------------------------------------------------------------------------------------   
# Token class
# dispatch function
# convert_to_error                        
# RemoteError class                         
# all_methods function
# public_methods function                           
# class Server class
# class State setting
# listener_client function 
# BaseManager class
# ProcessLocalSet class
# BaseProxy class
# RebuildProxy class
# MakeProxyType function
# AutoProxy function                              
# Value class                              
# Array function                              
# IteratorProxy class                              
# AcquirerProxy class                              
# ConditionProxy class                              
# EventProxy class                              
# NamespaceProxy class                             
# ValueProxy class                              
# BaseListProxy type                              
# ListProxy class                              
# DictProxy type                              
# ArrayProxy type                              
# PoolProxy type                              
# SyncManager class                              

# -------------------------------------------------------------------------------------------------
# code of managers.py    
# -------------------------------------------------------------------------------------------------
# SyncManager2Xi.register('Queue', queue.Queue)
# SyncManager2Xi.register('JoinableQueue', queue.Queue)
# SyncManager2Xi.register('Event', threading.Event, EventProxy)
# SyncManager2Xi.register('Lock', threading.Lock, AcquirerProxy)
# SyncManager2Xi.register('RLock', threading.RLock, AcquirerProxy)
# SyncManager2Xi.register('Semaphore', threading.Semaphore, AcquirerProxy)
# SyncManager2Xi.register('BoundedSemaphore', threading.BoundedSemaphore, AcquirerProxy)
# SyncManager2Xi.register('Condition', threading.Condition, ConditionProxy)
# SyncManager2Xi.register('Pool', Pool, PoolProxy)
# SyncManager2Xi.register('list', list, ListProxy)
# SyncManager2Xi.register('dict', dict, DictProxy)
# SyncManager2Xi.register('Value', Value, ValueProxy)
# SyncManager2Xi.register('Array', Array, ArrayProxy)
# SyncManager2Xi.register('Namespace', Namespace, NamespaceProxy)
# types returned by methods of PoolProxy
# SyncManager.register('Iterator', proxytype=IteratorProxy, create_method=False)
# SyncManager.register('AsyncResult', create_method=False)

# -------------------------------------------------------------------------------------------------
# code of this module    
# -------------------------------------------------------------------------------------------------
SyncManager2Xi.register('Queue2Xi', Queue2Xi)
SyncManager2Xi.register('JoinableQueue2Xi', Queue2Xi)
SyncManager2Xi.register('Event2Xi', threading.Event, EventProxy2Xi)
SyncManager2Xi.register('Lock2Xi', threading.Lock, AcquirerProxy2Xi)
SyncManager2Xi.register('RLock2Xi', threading.RLock, AcquirerProxy2Xi)
SyncManager2Xi.register('Semaphore2Xi', threading.Semaphore, AcquirerProxy2Xi)
SyncManager2Xi.register('BoundedSemaphore2Xi', threading.BoundedSemaphore, AcquirerProxy2Xi)
SyncManager2Xi.register('Condition2Xi', threading.Condition, ConditionProxy2Xi)
SyncManager2Xi.register('Pool2Xi', Pool2Xi, PoolProxy2Xi)
SyncManager2Xi.register('list', list, ListProxy2Xi)
SyncManager2Xi.register('dict', dict, DictProxy2Xi)
SyncManager2Xi.register('Value2Xi', Value2Xi, ValueProxy2Xi)
SyncManager2Xi.register('ArrayFunction2Xi', ArrayFunction2Xi, ArrayProxy2Xi)
SyncManager2Xi.register('Namespace2Xi', Namespace2Xi, NamespaceProxy2Xi)
# types returned by methods of PoolProxy
SyncManager2Xi.register('Iterator2Xi', proxytype=IteratorProxy2Xi, create_method=False)
SyncManager2Xi.register('AsyncResult2Xi', create_method=False)

# -------------------------------------------------------------------------------------------------
# test                              
# -------------------------------------------------------------------------------------------------
def test():
    print("\n =================================")
    print("\n test_managers.py: tests dragonized managers.py")
    print("\n =================================")

# -------------------------------------------------------------------------------------------------
# main function                              
# -------------------------------------------------------------------------------------------------
def main():

    test()
    

         

# -------------------------------------------------------------------------------------------------
#                               
# -------------------------------------------------------------------------------------------------
if __name__ == '__main__':
    main()          
    

# -------------------------------------------------------------------------------------------------
# end of test_managers.py                               
# -------------------------------------------------------------------------------------------------


